@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -54,7 +54,10 @@ class ExecutionsClientMeta(type):
     _transport_registry["grpc"] = ExecutionsGrpcTransport
     _transport_registry["grpc_asyncio"] = ExecutionsGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[ExecutionsTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[ExecutionsTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -162,11 +165,17 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def execution_path(
-        project: str, location: str, workflow: str, execution: str,
+        project: str,
+        location: str,
+        workflow: str,
+        execution: str,
     ) -> str:
         """Returns a fully-qualified execution string."""
         return "projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}".format(
-            project=project, location=location, workflow=workflow, execution=execution,
+            project=project,
+            location=location,
+            workflow=workflow,
+            execution=execution,
         )
 
     @staticmethod
@@ -179,10 +188,16 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def workflow_path(project: str, location: str, workflow: str,) -> str:
+    def workflow_path(
+        project: str,
+        location: str,
+        workflow: str,
+    ) -> str:
         """Returns a fully-qualified workflow string."""
         return "projects/{project}/locations/{location}/workflows/{workflow}".format(
-            project=project, location=location, workflow=workflow,
+            project=project,
+            location=location,
+            workflow=workflow,
         )
 
     @staticmethod
@@ -195,7 +210,9 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -208,9 +225,13 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -219,9 +240,13 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -230,9 +255,13 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -241,10 +270,14 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -433,9 +466,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         executions are ordered by their start time (newest
         first).
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
@@ -517,12 +548,20 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListExecutionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -541,9 +580,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         r"""Creates a new execution using the latest revision of
         the given workflow.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
@@ -629,7 +666,12 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -645,8 +687,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
     ) -> executions.Execution:
         r"""Returns an execution of the given name.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
@@ -722,7 +763,12 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -738,8 +784,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
     ) -> executions.Execution:
         r"""Cancels an execution of the given name.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
@@ -815,7 +860,12 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -836,7 +886,9 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflow",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflow",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
