@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -217,14 +217,13 @@ class ExecutionsAsyncClient:
         executions are ordered by their start time (newest
         first).
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1beta
 
-            def sample_list_executions():
+            async def sample_list_executions():
                 # Create a client
-                client = executions_v1beta.ExecutionsClient()
+                client = executions_v1beta.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1beta.ListExecutionsRequest(
@@ -235,7 +234,7 @@ class ExecutionsAsyncClient:
                 page_result = client.list_executions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -300,12 +299,20 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListExecutionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -324,14 +331,13 @@ class ExecutionsAsyncClient:
         r"""Creates a new execution using the latest revision of
         the given workflow.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1beta
 
-            def sample_create_execution():
+            async def sample_create_execution():
                 # Create a client
-                client = executions_v1beta.ExecutionsClient()
+                client = executions_v1beta.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1beta.CreateExecutionRequest(
@@ -339,7 +345,7 @@ class ExecutionsAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_execution(request=request)
+                response = await client.create_execution(request=request)
 
                 # Handle the response
                 print(response)
@@ -411,7 +417,12 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -427,13 +438,13 @@ class ExecutionsAsyncClient:
     ) -> executions.Execution:
         r"""Returns an execution of the given name.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1beta
 
-            def sample_get_execution():
+            async def sample_get_execution():
                 # Create a client
-                client = executions_v1beta.ExecutionsClient()
+                client = executions_v1beta.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1beta.GetExecutionRequest(
@@ -441,7 +452,7 @@ class ExecutionsAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_execution(request=request)
+                response = await client.get_execution(request=request)
 
                 # Handle the response
                 print(response)
@@ -503,7 +514,12 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -519,13 +535,13 @@ class ExecutionsAsyncClient:
     ) -> executions.Execution:
         r"""Cancels an execution of the given name.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1beta
 
-            def sample_cancel_execution():
+            async def sample_cancel_execution():
                 # Create a client
-                client = executions_v1beta.ExecutionsClient()
+                client = executions_v1beta.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1beta.CancelExecutionRequest(
@@ -533,7 +549,7 @@ class ExecutionsAsyncClient:
                 )
 
                 # Make the request
-                response = client.cancel_execution(request=request)
+                response = await client.cancel_execution(request=request)
 
                 # Handle the response
                 print(response)
@@ -595,7 +611,12 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -609,7 +630,9 @@ class ExecutionsAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflow",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflow",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
