@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -58,7 +58,10 @@ class WorkflowsClientMeta(type):
     _transport_registry["grpc"] = WorkflowsGrpcTransport
     _transport_registry["grpc_asyncio"] = WorkflowsGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[WorkflowsTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[WorkflowsTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -166,10 +169,16 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         return self._transport
 
     @staticmethod
-    def workflow_path(project: str, location: str, workflow: str,) -> str:
+    def workflow_path(
+        project: str,
+        location: str,
+        workflow: str,
+    ) -> str:
         """Returns a fully-qualified workflow string."""
         return "projects/{project}/locations/{location}/workflows/{workflow}".format(
-            project=project, location=location, workflow=workflow,
+            project=project,
+            location=location,
+            workflow=workflow,
         )
 
     @staticmethod
@@ -182,7 +191,9 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -195,9 +206,13 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -206,9 +221,13 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -217,9 +236,13 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -228,10 +251,14 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -417,9 +444,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         r"""Lists Workflows in a given project and location.
         The default order is not specified.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
@@ -501,12 +526,20 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListWorkflowsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -523,8 +556,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
     ) -> workflows.Workflow:
         r"""Gets details of a single Workflow.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
@@ -600,7 +632,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -621,9 +658,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         running operation will return
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
@@ -736,7 +771,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -762,9 +802,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         This method also cancels and deletes all running
         executions of the workflow.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
@@ -857,7 +895,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -887,9 +930,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         update operation. In that case, such revision will be
         used in new workflow executions.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
@@ -984,7 +1025,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1013,7 +1059,9 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflows",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflows",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
